Ext.namespace('dSA', 'dSA.util');

dSA.util.shortDSID = function(dsid) {
    if (dsid.length > 8) {
        return dsid.slice(dsid.length - 8);
    } else {
        return dsid;
    }
};

dSA.util.getName = function(name) {
    if ((name === undefined) || (name.length === 0)) {
        return '<i>' + dSA._("no name") + '</i>';
    } else {
        return name;
    }
};

dSA.util.getData = function(response)
{
    var json = Ext.util.JSON.decode(response.responseText);
    if (json.success === false)
    {
        throw json.message;
    }

    if (json.data === undefined)
    {
        throw _("could not retrieve data from response");
    }
    return json.data;
};

dSA.util.checkResponse = function(response)
{
    var json = Ext.util.JSON.decode(response.responseText);
    if (json.success === false)
    {
        throw json.message;
    }
};

dSA.util.failureMessage = function(response)
{
    try 
    {
        var json = Ext.util.JSON.decode(response.responseText);
        if (json.message)
        {
            return json.message;
        }
    }
    catch (error)
    {
        // when the dSA is not running lighttpds proxy will return an
        // HTTP 500 along with some HTML which will cause a JSON parsing error
        return ""; 
    }
};

dSA.util.colon = function(text)
{
    return text === "" ? text : ": " + text;
};


// this function never fails
dSA.util.getNumDevices = function(dsid, callback)
{
    if (callback === undefined)
    {
        return;
    }

    Ext.Ajax.request({
        url: '/dsa/json/hardware/get',
        disableCaching: true,
        method: 'GET',
        params:
        {
            dsm: dsid
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if ((data.dsms === undefined) && (data.dsms.length === 0))
                {
                    callback(0);
                }

                if (data.dsms[0].dsid === dsid) {
                    callback(data.dsms[0].devices.length);
                    return;
                }
            }
            catch (error)
            {}

            callback(0);
        },
        failure: function(response, opts)
        {
            callback(0);
        }
    });
};

dSA.util.unmask = function(maskEl)
{
    if (maskEl !== undefined)
    {
        maskEl.unmask();
    }
};

dSA.util.mask = function(maskEl, text)
{
    if (maskEl !== undefined)
    {
        maskEl.mask();
    }
};
